<?php
/**
 * This file is responsible for displaying and managing the plugin's admin interface.
 * It allows administrators to view and update plugin settings, such as saving and
 * loading preferences via AJAX.
 */

// Dynamically set the plugin slug by getting the plugin folder name
$plugin_slug = basename(dirname(__FILE__)); // 'sample-plugin'

// Handle form submission based on 'action'
if (isset($_POST['action'])) {
	if ($_POST['action'] == 'string_value') {
		// Save string preference
		$string_value = $_POST['string_value'] ?? '';
		set_plugin_pref($plugin_slug, 'string_value', $string_value);
		show_alert('String preference saved!', 'success');
	}
	
	if ($_POST['action'] == 'number_value') {
		// Save number preference
		$number_value = $_POST['number_value'] ?? 0;
		set_plugin_pref($plugin_slug, 'number_value', $number_value);
		show_alert('Number preference saved!', 'success');
	}
	
	if ($_POST['action'] == 'bool_value') {
		// Save boolean preference
		$bool_value = isset($_POST['bool_value']) ? 'true' : 'false';
		set_plugin_pref($plugin_slug, 'bool_value', $bool_value);
		show_alert('Boolean preference saved!', 'success');
	}
}
?>

<div class="section">
	<div class="bs-callout bs-callout-info">
		Sample Plugin: Use this plugin as a starter or to learn how to save and load preferences.
	</div>

	<h4>Basic Plugin Preferences</h4>

	<!-- String Preference -->
	<div class="mb-3">
		<p><b>Save plugin string preference</b></p>
		<form method="post">
			<input type="hidden" name="action" value="string_value">
			<?php $string_value = get_plugin_pref($plugin_slug, 'string_value', ''); ?>
			<input type="text" class="form-control" name="string_value" value="<?php echo htmlspecialchars($string_value); ?>">
			<small class="form-text text-muted">
				Current value: <?php echo !empty($string_value) ? htmlspecialchars($string_value) : 'No value set'; ?>
			</small>
			<br>
			<button class="btn btn-primary btn-md mt-2">Save</button>
		</form>
	</div>

	<!-- Number Preference -->
	<div class="mb-3">
		<p><b>Save plugin number preference</b></p>
		<form method="post">
			<input type="hidden" name="action" value="number_value">
			<?php $number_value = get_plugin_pref($plugin_slug, 'number_value', 0); ?>
			<input type="number" class="form-control" name="number_value" value="<?php echo htmlspecialchars($number_value); ?>">
			<small class="form-text text-muted">
				Current value: <?php echo htmlspecialchars($number_value); ?>
			</small>
			<br>
			<button class="btn btn-primary btn-md mt-2">Save</button>
		</form>
	</div>

	<!-- Boolean Preference -->
	<div class="mb-3">
		<p><b>Save plugin boolean preference</b></p>
		<form method="post">
			<input type="hidden" name="action" value="bool_value">
			<?php $bool_value = get_plugin_pref_bool($plugin_slug, 'bool_value', false); ?>
			<div class="form-check">
				<input type="checkbox" name="bool_value" class="form-check-input" id="bool_value" <?php echo $bool_value ? 'checked' : ''; ?>>
				<label class="form-check-label" for="bool_value">Enable</label>
			</div>
			<small class="form-text text-muted">
				Current value: <?php echo $bool_value ? 'True' : 'False'; ?>
			</small>
			<br>
			<button class="btn btn-primary btn-md mt-2">Save</button>
		</form>
	</div>
</div>

<div class="section">
	<h4>Save String Preference via AJAX</h4>
	<div class="mb-3">
		<form id="string-value-form" class="ajax-form" method="post">
			<input type="hidden" name="action" value="string_value">
			<?php $string_value = get_plugin_pref($plugin_slug, 'string_value', ''); ?>
			<input type="text" class="form-control" name="string_value" value="<?php echo htmlspecialchars($string_value); ?>">
			<button class="btn btn-primary btn-md mt-2">Save</button>
		</form>
		<small id="response-message" class="form-text text-muted mt-2"></small> <!-- This will display the AJAX response -->
	</div>
</div>

<script>
document.addEventListener("DOMContentLoaded", function() {
    // Handle the "string_value" form submission via AJAX
    document.getElementById('string-value-form').addEventListener('submit', function(event) {
        event.preventDefault(); // Prevent default form submission

        let formData = new FormData(this);
        
        fetch('/content/plugins/<?php echo $plugin_slug ?>/ajax-handler.php', {
            method: 'POST',
            body: formData
        })
        .then(response => response.text())
        .then(data => {
            document.getElementById('response-message').innerHTML = data; // Display the response message
        })
        .catch(error => console.error('Error:', error));
    });
});
</script>